@@ -1,19 +1,21 @@
-def convert_imageattachment(field):
+from django.conf import settings
+
+
+def convert_avatar(field):
 
     img = field.field.to_python(field.value())
 
     if img:
-        return """<img src="%s"/>""" % img.get_profile_middle_url()
+        return """<img src="%s"/>""" % img.get_avatar_url()
     else:
-        return ""
+        return """<img src="%s"/>""" % settings.DEFAULT_AVATAR_URL
 
 def convert_nothing(field):
 
               return field.value()
 
 
-CONVERTERS = {'SingleImageAttachmentField':
-                  convert_imageattachment}
+CONVERTERS = {'AvatarField': convert_avatar}
 
 
 def value_to_html(field):
